@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,7 +31,7 @@ class FilterConvertToSieveResultDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit FilterConvertToSieveResultDialog(QWidget *parent = Q_NULLPTR);
+    explicit FilterConvertToSieveResultDialog(QWidget *parent = nullptr);
     ~FilterConvertToSieveResultDialog();
 
     void setCode(const QString &code);
