@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -47,7 +47,7 @@ FilterImporterProcmail::~FilterImporterProcmail()
 
 void FilterImporterProcmail::readStream(QTextStream &stream)
 {
-    MailFilter *filter = 0;
+    MailFilter *filter = nullptr;
     while (!stream.atEnd()) {
         QString line = stream.readLine();
         qCDebug(MAILCOMMON_LOG) << " line :" << line << " filter " << filter;
