@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2011-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -45,7 +45,7 @@ FilterImporterThunderbird::~FilterImporterThunderbird()
 
 void FilterImporterThunderbird::readStream(QTextStream &stream)
 {
-    MailFilter *filter = Q_NULLPTR;
+    MailFilter *filter = nullptr;
     while (!stream.atEnd()) {
         QString line = stream.readLine();
         qCDebug(MAILCOMMON_LOG) << " line :" << line << " filter " << filter;
@@ -99,7 +99,7 @@ MailCommon::MailFilter *FilterImporterThunderbird::parseLine(QTextStream &stream
                         value = QStringLiteral("5 (Lowest)");
                     }
                     lstValue << value;
-                    value = lstValue.join(QStringLiteral("\t"));
+                    value = lstValue.join(QLatin1Char('\t'));
                     actionName = QStringLiteral("add header");
                 } else if (actionName == QLatin1String("copy") || actionName == QLatin1String("transfer")) {
                     QUrl url = QUrl::fromLocalFile(value);
