@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,14 +19,14 @@
 #define INVALIDFILTERINFOWIDGET_H
 
 #include <KMessageWidget>
-#include "mailcommon_export.h"
+#include "mailcommon_private_export.h"
 namespace MailCommon
 {
-class MAILCOMMON_EXPORT InvalidFilterInfoWidget : public KMessageWidget
+class MAILCOMMON_TESTS_EXPORT InvalidFilterInfoWidget : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit InvalidFilterInfoWidget(QWidget *parent = Q_NULLPTR);
+    explicit InvalidFilterInfoWidget(QWidget *parent = nullptr);
     ~InvalidFilterInfoWidget();
 public Q_SLOTS:
     void slotShowDetails(const QString &details);
