@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -410,7 +410,7 @@ QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, boo
     // report on invalid filters:
     if (!emptyFilters.empty()) {
         if (closeAfterSaving) {
-            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(Q_NULLPTR);
+            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(nullptr);
             dlg->setInvalidFilters(listInvalidFilters);
             if (!dlg->exec()) {
                 Q_EMIT abortClosing();
@@ -418,7 +418,7 @@ QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, boo
             }
             delete dlg;
         } else {
-            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(0);
+            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(nullptr);
             dlg->setInvalidFilters(listInvalidFilters);
             if (!dlg->exec()) {
                 wasCanceled = true;
@@ -524,7 +524,8 @@ void KMFilterListBox::slotDelete()
 
     Q_EMIT resetWidgets();
 
-    Q_FOREACH (QListWidgetItem *item, mListWidget->selectedItems()) {
+    const QList<QListWidgetItem *> lstItems = mListWidget->selectedItems();
+    for (QListWidgetItem *item : lstItems) {
         QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
 
         MailCommon::MailFilter *filter = itemFilter->filter();
@@ -571,7 +572,7 @@ void KMFilterListBox::slotTop()
         return;
     }
 
-    QListWidgetItem *item = 0;
+    QListWidgetItem *item = nullptr;
     bool wasMoved = false;
     for (int i = 0; i < numberOfItem; ++i) {
         const int posItem = mListWidget->row(listWidgetItem.at(i));
@@ -620,7 +621,7 @@ QStringList KMFilterListBox::selectedFilterId(SearchRule::RequiredPart &required
 
 void KMFilterListBox::slotBottom()
 {
-    QList<QListWidgetItem *> listWidgetItem = selectedFilter();
+    const QList<QListWidgetItem *> listWidgetItem = selectedFilter();
     if (listWidgetItem.isEmpty()) {
         return;
     }
@@ -632,7 +633,7 @@ void KMFilterListBox::slotBottom()
         return;
     }
 
-    QListWidgetItem *item = Q_NULLPTR;
+    QListWidgetItem *item = nullptr;
     int j = 0;
     bool wasMoved = false;
     for (int i = numberOfItem - 1; i >= 0; --i, j++) {
@@ -653,7 +654,7 @@ void KMFilterListBox::slotBottom()
 
 void KMFilterListBox::slotUp()
 {
-    QList<QListWidgetItem *> listWidgetItem = selectedFilter();
+    const QList<QListWidgetItem *> listWidgetItem = selectedFilter();
     if (listWidgetItem.isEmpty()) {
         return;
     }
@@ -681,7 +682,7 @@ void KMFilterListBox::slotUp()
 
 void KMFilterListBox::slotDown()
 {
-    QList<QListWidgetItem *> listWidgetItem = selectedFilter();
+    const QList<QListWidgetItem *> listWidgetItem = selectedFilter();
     if (listWidgetItem.isEmpty()) {
         return;
     }
@@ -801,7 +802,7 @@ void KMFilterListBox::loadFilterList(bool createDummyFilter)
     mListWidget->clear();
 
     const QList<MailFilter *> filters = MailCommon::FilterManager::instance()->filters();
-    foreach (MailFilter *filter, filters) {
+    for (MailFilter *filter : filters) {
         QListWidgetFilterItem *item =
             new QListWidgetFilterItem(filter->pattern()->name(), mListWidget);
         item->setFilter(new MailFilter(*filter));
@@ -872,7 +873,7 @@ void KMFilterListBox::swapNeighbouringFilters(int untouchedOne, int movedOne)
 }
 
 QListWidgetFilterItem::QListWidgetFilterItem(const QString &text, QListWidget *parent)
-    : QListWidgetItem(text, parent), mFilter(0)
+    : QListWidgetItem(text, parent), mFilter(nullptr)
 {
 }
 
