@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2004 Carsten Burghardt <burghardt@kde.org>
- * Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ class FolderRequesterPrivate
 {
 public:
     FolderRequesterPrivate()
-        : mEdit(Q_NULLPTR),
+        : mEdit(nullptr),
           mMustBeReadWrite(true),
           mShowOutbox(true),
           mNotCreateNewFolder(false)
