@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,6 +17,7 @@
 */
 
 #include "foldertreeview.h"
+#include "util/mailutil_p.h"
 #include "kernel/mailkernel.h"
 
 #include <CollectionStatistics>
@@ -394,7 +395,7 @@ void FolderTreeView::slotFocusPrevFolder()
 
 void FolderTreeView::slotFocusFirstFolder()
 {
-    const QModelIndex first = moveCursor(QAbstractItemView::MoveHome, 0);
+    const QModelIndex first = moveCursor(QAbstractItemView::MoveHome, nullptr);
     if (first.isValid()) {
         setCurrentModelIndex(first);
     }
@@ -402,7 +403,7 @@ void FolderTreeView::slotFocusFirstFolder()
 
 void FolderTreeView::slotFocusLastFolder()
 {
-    const QModelIndex last = moveCursor(QAbstractItemView::MoveEnd, 0);
+    const QModelIndex last = moveCursor(QAbstractItemView::MoveEnd, nullptr);
     if (last.isValid()) {
         setCurrentModelIndex(last);
     }
@@ -506,7 +507,7 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
             i18n("Go to Next Unread Message"),
             KGuiItem(i18n("Go To")),
             KGuiItem(i18n("Do Not Go To")),     // defaults
-            QStringLiteral(":kmail_AskNextFolder"), 0);
+            QStringLiteral(":kmail_AskNextFolder"), nullptr);
 
     return (result == KMessageBox::Yes);
 }
@@ -556,7 +557,7 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current,
                                     KGuiItem(i18n("Go To")),
                                     KGuiItem(i18n("Do Not Go To")),     // defaults
                                     QStringLiteral(":kmail_AskNextFolder"),
-                                    0) == KMessageBox::No) {
+                                    nullptr) == KMessageBox::No) {
                             return true; // assume selected (do not continue looping)
                         }
 
@@ -586,7 +587,7 @@ Akonadi::Collection FolderTreeView::currentFolder() const
 void FolderTreeView::mousePressEvent(QMouseEvent *e)
 {
     const bool buttonPressedIsMiddle = (e->button() == Qt::MidButton);
-    Q_EMIT prefereCreateNewTab(buttonPressedIsMiddle);
+    Q_EMIT newTabRequested(buttonPressedIsMiddle);
     EntityTreeView::mousePressEvent(e);
 }
 
