@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,6 +18,7 @@
 #include "addtagdialog.h"
 #include "tag/tagwidget.h"
 #include "mailcommon_debug.h"
+#include "helper_p.h"
 
 #include <KLocalizedString>
 #include <KLineEdit>
@@ -34,8 +35,8 @@ class MailCommon::AddTagDialogPrivate
 {
 public:
     AddTagDialogPrivate()
-        : mTagWidget(Q_NULLPTR),
-          mOkButton(Q_NULLPTR)
+        : mTagWidget(nullptr),
+          mOkButton(nullptr)
     {
 
     }
@@ -91,7 +92,7 @@ void AddTagDialog::slotSave()
 {
     const QString name(d->mTagWidget->tagNameLineEdit()->text());
 
-    Q_FOREACH (const MailCommon::Tag::Ptr &tag, d->mTags) {
+    for (const MailCommon::Tag::Ptr &tag : qAsConst(d->mTags)) {
         if (tag->name() == name) {
             KMessageBox::error(this, i18n("Tag %1 already exists", name));
             d->mTagWidget->tagNameLineEdit()->setFocus();
