@@ -37,6 +37,7 @@
 *******************************************************************************/
 
 #include "mailutil.h"
+#include "mailutil_p.h"
 
 #include "mailcommon_debug.h"
 #include "calendarinterface.h"
@@ -138,7 +139,8 @@ bool MailCommon::Util::showJobErrorMessage(KJob *job)
 Akonadi::AgentInstance::List MailCommon::Util::agentInstances(bool excludeMailDispacher)
 {
     Akonadi::AgentInstance::List relevantInstances;
-    foreach (const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances()) {
+    const Akonadi::AgentInstance::List agentList = Akonadi::AgentManager::self()->instances();
+    for (const Akonadi::AgentInstance &instance : agentList) {
         const QStringList capabilities(instance.type().capabilities());
         if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
             if (capabilities.contains(QStringLiteral("Resource")) &&
@@ -352,19 +354,19 @@ QString MailCommon::Util::convertFolderPathToCollectionStr(const QString &folder
 
 bool MailCommon::Util::foundMailer()
 {
-    QStringList lst;
-    lst << MailImporter::FilterEvolution::defaultSettingsPath();
-    lst << MailImporter::FilterEvolution_v2::defaultSettingsPath();
-    lst << MailImporter::FilterEvolution_v3::defaultSettingsPath();
-    lst << MailImporter::FilterBalsa::defaultSettingsPath();
-    lst << MailImporter::FilterClawsMail::defaultSettingsPath();
-    lst << MailImporter::FilterOpera::defaultSettingsPath();
-    lst << MailImporter::FilterSylpheed::defaultSettingsPath();
-    lst << MailImporter::FilterThunderbird::defaultSettingsPath();
-    lst << MailImporter::OtherMailerUtil::trojitaDefaultPath();
-    lst << MailImporter::FilterIcedove::defaultSettingsPath();
+    const QStringList lst = { MailImporter::FilterEvolution::defaultSettingsPath(),
+                              MailImporter::FilterEvolution_v2::defaultSettingsPath(),
+                              MailImporter::FilterEvolution_v3::defaultSettingsPath(),
+                              MailImporter::FilterBalsa::defaultSettingsPath(),
+                              MailImporter::FilterClawsMail::defaultSettingsPath(),
+                              MailImporter::FilterOpera::defaultSettingsPath(),
+                              MailImporter::FilterSylpheed::defaultSettingsPath(),
+                              MailImporter::FilterThunderbird::defaultSettingsPath(),
+                              MailImporter::OtherMailerUtil::trojitaDefaultPath(),
+                              MailImporter::FilterIcedove::defaultSettingsPath(),
+                              MailImporter::OtherMailerUtil::gearyDefaultPath()};
 
-    Q_FOREACH (const QString &path, lst) {
+    for (const QString &path : lst) {
         QDir directory(path);
         if (directory.exists()) {
             return true;
@@ -375,7 +377,7 @@ bool MailCommon::Util::foundMailer()
 
 MailCommon::ExpireCollectionAttribute *MailCommon::Util::expirationCollectionAttribute(const Akonadi::Collection &collection, bool &mustDeleteExpirationAttribute)
 {
-    MailCommon::ExpireCollectionAttribute *attr = Q_NULLPTR;
+    MailCommon::ExpireCollectionAttribute *attr = nullptr;
     if (collection.hasAttribute<MailCommon::ExpireCollectionAttribute>()) {
         attr = collection.attribute<MailCommon::ExpireCollectionAttribute>();
         mustDeleteExpirationAttribute = false;
