@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -33,7 +33,7 @@ class MAILCOMMON_EXPORT FavoriteCollectionWidget : public Akonadi::EntityListVie
 {
     Q_OBJECT
 public:
-    explicit FavoriteCollectionWidget(KXMLGUIClient *xmlGuiClient, QWidget *parent = Q_NULLPTR);
+    explicit FavoriteCollectionWidget(KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr);
     ~FavoriteCollectionWidget();
 
     void readConfig();
@@ -50,6 +50,10 @@ protected Q_SLOTS:
 protected:
     void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
+    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+Q_SIGNALS:
+    void newTabRequested(bool);
+
 private:
     void createMenu(KActionCollection *ac);
     class Private;
