@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
-  Copyright (c) 2014-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,9 +36,7 @@
 #include <KIdentityManagement/IdentityCombo>
 #include <KIdentityManagement/IdentityManager>
 
-#include <MailTransport/Transport>
 #include <MailTransport/TransportComboBox>
-#include <MailTransport/TransportManager>
 
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -62,14 +60,14 @@ class Q_DECL_HIDDEN RedirectDialog::Private
 public:
     Private(RedirectDialog *qq, RedirectDialog::SendMode mode)
         : q(qq),
-          mEditTo(Q_NULLPTR),
-          mEditCc(Q_NULLPTR),
-          mEditBcc(Q_NULLPTR),
+          mEditTo(nullptr),
+          mEditCc(nullptr),
+          mEditBcc(nullptr),
           mSendMode(mode),
-          mComboboxIdentity(Q_NULLPTR),
-          mTransportCombobox(Q_NULLPTR),
-          mUser1Button(Q_NULLPTR),
-          mUser2Button(Q_NULLPTR)
+          mComboboxIdentity(nullptr),
+          mTransportCombobox(nullptr),
+          mUser1Button(nullptr),
+          mUser2Button(nullptr)
 
     {
     }
@@ -135,12 +133,12 @@ RedirectDialog::RedirectDialog(SendMode mode, QWidget *parent)
     : QDialog(parent), d(new Private(this, mode))
 {
     setWindowTitle(i18n("Redirect Message"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
     QVBoxLayout *topLayout = new QVBoxLayout;
     setLayout(topLayout);
-    d->mUser1Button = new QPushButton;
+    d->mUser1Button = new QPushButton(this);
     buttonBox->addButton(d->mUser1Button, QDialogButtonBox::ActionRole);
-    d->mUser2Button = new QPushButton;
+    d->mUser2Button = new QPushButton(this);
     buttonBox->addButton(d->mUser2Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &RedirectDialog::reject);
     if (mode == SendNow) {
